@@ -22,7 +22,7 @@ class FakeBlock:
 		self.content = value
 
 	def render(self):
-		return self.content
+		return "<pre>%s</pre>" % self.content
 
 	def __str__(self):
 		return self.render()
@@ -41,7 +41,10 @@ class BlockManager:
 		else :
 			message = "Could not find block with name : %s" % name
 			if len(BLOCKS) > 0 :
-				message = "%s \n Valid Block names are : %s" % (message, ",".join([ name for name,data in BLOCKS.items() ]))
+				message = "%s \n Because : valid block names are \n\t %s" % (message, ",".join([ name for name,data in BLOCKS.items() ]))
+			else :
+				message = "%s \n Blockmanager is not managing any blocks" % message
+
 			LOGGER.log(logging.DEBUG, message)
 			block = FakeBlock(message)
 		return block
